Struct focus_ami::config::Config

source ·
pub struct Config { /* private fields */ }

Implementations

source

impl Config

source

pub fn new( kill_time: u8, work_time: u16, password: String, processes: HashSet<String> ) -> Self

Creates a new config from the parameters

source

pub fn get_or_create(file: Option<PathBuf>) -> (Config, PathBuf)

Get the config object from the config.yaml file.

Panics
  • if access to the file is compromised anywhere in it’s path. Lack of access to the config directory is distinguished from lack of access to the file
source

pub fn write_config(&self, filename: &Path)

source

pub fn contains(&self, proc: &str) -> bool

Returns true if process is in process list, otherwise it returns false.

source

pub fn get_work_time(&self) -> Duration

returns a Duration from the work_time. It transforms from minutes to seconds

source

pub fn get_work_time_as_min(&self) -> u16

source

pub fn get_kill_time(&self) -> Duration

source

pub fn get_kill_time_as_seconfs(&self) -> u8

source

pub fn print_curr_state(&self)

source

pub fn edit(self) -> Config

source

pub fn remain(&self, beg: Instant) -> Config

source

pub fn add_time(&self, time: u8) -> Config

source

pub fn create() -> Config

Helps the user create a config, providing sane defaults and a sense