This function is the one that sends the kill signals to the processes It waits for a Config to be sent to it to start blocking.
It runs on a while that
- checks if you have run out of time
- Sees if config has changed
- gets all running processes
- kills those in the processes list of the running configuration
- sleeps