Traits
The implementor of this trait has a field that can be guessed up to three times
Functions
Non blocking string input.
It sends whatever is inputed and then dies.
It can be “polled” with try_recv
prints a 80 character wide string of -
Gets anything that implements FromStr or q
Adds or removes processes from the current processes HashSet It admits four types of interactions
Gets a vector that stops at a none parameter. It is append only. It must be provided with a closure (or function) that returns an option You can get such a thing from a function that returns error using