Trait focus_ami::utils::GuessablePassword
source · pub trait GuessablePassword {
fn get_password(&self) -> String;
fn check_pass(&self, checks: Option<u8>) -> bool { ... }
}Expand description
The implementor of this trait has a field that can be guessed up to three times
Required Methods
sourcefn get_password(&self) -> String
fn get_password(&self) -> String
The field must be accessible to the trait through this method.
Provided Methods
sourcefn check_pass(&self, checks: Option<u8>) -> bool
fn check_pass(&self, checks: Option<u8>) -> bool
When called starts a series of interactions with the user that result
in a boolean
It returns true whenever the Password is guessed right and false
When it has been guessed wrongly three times